/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.datastore.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for GqlQuery.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Cloud Datastore API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class GqlQuery extends GenericJson {

  /**
   * When false, the query string must not contain a literal.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean allowLiteral;

  /**
   * A named argument must set field GqlQueryArg.name. No two named arguments may have the same
   * name. For each non-reserved named binding site in the query string, there must be a named
   * argument with that name, but not necessarily the inverse.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<GqlQueryArg> nameArgs;

  static {
    // hack to force ProGuard to consider GqlQueryArg used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(GqlQueryArg.class);
  }

  /**
   * Numbered binding site @1 references the first numbered argument, effectively using 1-based
   * indexing, rather than the usual 0. A numbered argument must NOT set field GqlQueryArg.name. For
   * each binding site numbered i in query_string, there must be an ith numbered argument. The
   * inverse must also be true.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<GqlQueryArg> numberArgs;

  static {
    // hack to force ProGuard to consider GqlQueryArg used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(GqlQueryArg.class);
  }

  /**
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String queryString;

  /**
   * When false, the query string must not contain a literal.
   * The value returned may be {@code null}.
   */
  public Boolean getAllowLiteral() {
    return allowLiteral;
  }

  /**
   * When false, the query string must not contain a literal.
   * The value set may be {@code null}.
   */
  public GqlQuery setAllowLiteral(Boolean allowLiteral) {
    this.allowLiteral = allowLiteral;
    return this;
  }

  /**
   * A named argument must set field GqlQueryArg.name. No two named arguments may have the same
   * name. For each non-reserved named binding site in the query string, there must be a named
   * argument with that name, but not necessarily the inverse.
   * The value returned may be {@code null}.
   */
  public java.util.List<GqlQueryArg> getNameArgs() {
    return nameArgs;
  }

  /**
   * A named argument must set field GqlQueryArg.name. No two named arguments may have the same
   * name. For each non-reserved named binding site in the query string, there must be a named
   * argument with that name, but not necessarily the inverse.
   * The value set may be {@code null}.
   */
  public GqlQuery setNameArgs(java.util.List<GqlQueryArg> nameArgs) {
    this.nameArgs = nameArgs;
    return this;
  }

  /**
   * Numbered binding site @1 references the first numbered argument, effectively using 1-based
   * indexing, rather than the usual 0. A numbered argument must NOT set field GqlQueryArg.name. For
   * each binding site numbered i in query_string, there must be an ith numbered argument. The
   * inverse must also be true.
   * The value returned may be {@code null}.
   */
  public java.util.List<GqlQueryArg> getNumberArgs() {
    return numberArgs;
  }

  /**
   * Numbered binding site @1 references the first numbered argument, effectively using 1-based
   * indexing, rather than the usual 0. A numbered argument must NOT set field GqlQueryArg.name. For
   * each binding site numbered i in query_string, there must be an ith numbered argument. The
   * inverse must also be true.
   * The value set may be {@code null}.
   */
  public GqlQuery setNumberArgs(java.util.List<GqlQueryArg> numberArgs) {
    this.numberArgs = numberArgs;
    return this;
  }

  /**

   * The value returned may be {@code null}.
   */
  public String getQueryString() {
    return queryString;
  }

  /**

   * The value set may be {@code null}.
   */
  public GqlQuery setQueryString(String queryString) {
    this.queryString = queryString;
    return this;
  }

}
