/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.datastore.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for Mutation.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Google Cloud Datastore API. For a detailed
 * explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Mutation extends GenericJson {

  /**
   * Keys of entities to delete. Each key must have a complete key path and must not be reserved
   * /read-only.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Key> delete;

  static {
    // hack to force ProGuard to consider Key used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Key.class);
  }

  /**
   * Ignore a user specified read-only period. Optional.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean force;

  /**
   * Entities to insert. Each inserted entity's key must have a complete path and must not be
   * reserved/read-only.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Entity> insert;

  static {
    // hack to force ProGuard to consider Entity used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Entity.class);
  }

  /**
   * Insert entities with a newly allocated ID. Each inserted entity's key must omit the final
   * identifier in its path and must not be reserved/read-only.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Entity> insertAutoId;

  static {
    // hack to force ProGuard to consider Entity used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Entity.class);
  }

  /**
   * Entities to update. Each updated entity's key must have a complete path and must not be
   * reserved/read-only.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Entity> update;

  static {
    // hack to force ProGuard to consider Entity used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Entity.class);
  }

  /**
   * Entities to upsert. Each upserted entity's key must have a complete path and must not be
   * reserved/read-only.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Entity> upsert;

  static {
    // hack to force ProGuard to consider Entity used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Entity.class);
  }

  /**
   * Keys of entities to delete. Each key must have a complete key path and must not be reserved
   * /read-only.
   * The value returned may be {@code null}.
   */
  public java.util.List<Key> getDelete() {
    return delete;
  }

  /**
   * Keys of entities to delete. Each key must have a complete key path and must not be reserved
   * /read-only.
   * The value set may be {@code null}.
   */
  public Mutation setDelete(java.util.List<Key> delete) {
    this.delete = delete;
    return this;
  }

  /**
   * Ignore a user specified read-only period. Optional.
   * The value returned may be {@code null}.
   */
  public Boolean getForce() {
    return force;
  }

  /**
   * Ignore a user specified read-only period. Optional.
   * The value set may be {@code null}.
   */
  public Mutation setForce(Boolean force) {
    this.force = force;
    return this;
  }

  /**
   * Entities to insert. Each inserted entity's key must have a complete path and must not be
   * reserved/read-only.
   * The value returned may be {@code null}.
   */
  public java.util.List<Entity> getInsert() {
    return insert;
  }

  /**
   * Entities to insert. Each inserted entity's key must have a complete path and must not be
   * reserved/read-only.
   * The value set may be {@code null}.
   */
  public Mutation setInsert(java.util.List<Entity> insert) {
    this.insert = insert;
    return this;
  }

  /**
   * Insert entities with a newly allocated ID. Each inserted entity's key must omit the final
   * identifier in its path and must not be reserved/read-only.
   * The value returned may be {@code null}.
   */
  public java.util.List<Entity> getInsertAutoId() {
    return insertAutoId;
  }

  /**
   * Insert entities with a newly allocated ID. Each inserted entity's key must omit the final
   * identifier in its path and must not be reserved/read-only.
   * The value set may be {@code null}.
   */
  public Mutation setInsertAutoId(java.util.List<Entity> insertAutoId) {
    this.insertAutoId = insertAutoId;
    return this;
  }

  /**
   * Entities to update. Each updated entity's key must have a complete path and must not be
   * reserved/read-only.
   * The value returned may be {@code null}.
   */
  public java.util.List<Entity> getUpdate() {
    return update;
  }

  /**
   * Entities to update. Each updated entity's key must have a complete path and must not be
   * reserved/read-only.
   * The value set may be {@code null}.
   */
  public Mutation setUpdate(java.util.List<Entity> update) {
    this.update = update;
    return this;
  }

  /**
   * Entities to upsert. Each upserted entity's key must have a complete path and must not be
   * reserved/read-only.
   * The value returned may be {@code null}.
   */
  public java.util.List<Entity> getUpsert() {
    return upsert;
  }

  /**
   * Entities to upsert. Each upserted entity's key must have a complete path and must not be
   * reserved/read-only.
   * The value set may be {@code null}.
   */
  public Mutation setUpsert(java.util.List<Entity> upsert) {
    this.upsert = upsert;
    return this;
  }

}
